@@ -8,11 +8,16 @@ from .attachment import ImageAttachment, LocationAttachment, SplitAttachment, Em
 from .bot import Bot, Context
 from .callback import Callback
 
-__version__ = "0.2.0"
+__version__ = "0.2.2"
 __author__ = "Branden Colen"
 __all__ = [
-    "Bot", "Application", "Callback", "Context",
-    "ImageAttachment", "LocationAttachment",
-    "SplitAttachment", "EmojiAttachment",
-    "MentionsAttachment"
+    "Application",
+    "Bot",
+    "Callback",
+    "Context",
+    "EmojiAttachment",
+    "ImageAttachment",
+    "LocationAttachment",
+    "MentionsAttachment",
+    "SplitAttachment"
 ]
